library(ggplot2)
library(scales)

library(reshape2)
library(grid)
library(gmodels)

title.text<-element_text(size=12, face="bold")
tick.text<-element_text(size=10)

df=read.csv("contextAll.csv", header = TRUE, sep = ",")
head(df)

dfDog<-df[ which(df$Sound=="Dogs"),]
dfEng<-df[ which(df$Sound=="Engines"),]
dfTop<-df[ which(df$Sound=="Soundscape"),]
dfNat<-df[ which(df$Sound=="Nature"),]
dfMan<-df[ which(df$Sound=="Manmade"),]

#--- Age
Top<-c(sum(dfTop$Age=="18-29")/length(dfTop[,1]),sum(dfTop$Age=="30-39")/length(dfTop[,1]),sum(dfTop$Age=="40-49")/length(dfTop[,1]),sum(dfTop$Age=="50-59")/length(dfTop[,1]),sum(dfTop$Age=="60-69")/length(dfTop[,1]),sum(dfTop$Age=="70-79")/length(dfTop[,1]))
Nature<-c(sum(dfMan$Age=="18-29")/length(dfMan[,1]),sum(dfMan$Age=="30-39")/length(dfNat[,1]),sum(dfNat$Age=="40-49")/length(dfNat[,1]),sum(dfNat$Age=="50-59")/length(dfNat[,1]),sum(dfNat$Age=="60-69")/length(dfNat[,1]),sum(dfNat$Age=="70-79")/length(dfNat[,1]))
Manmade<-c(sum(dfMan$Age=="18-29")/length(dfMan[,1]),sum(dfMan$Age=="30-39")/length(dfMan[,1]),sum(dfMan$Age=="40-49")/length(dfMan[,1]),sum(dfMan$Age=="50-59")/length(dfMan[,1]),sum(dfMan$Age=="60-69")/length(dfMan[,1]),sum(dfMan$Age=="70-79")/length(dfMan[,1]))
Dog<-c(sum(dfDog$Age=="18-29")/length(dfDog[,1]),sum(dfDog$Age=="30-39")/length(dfDog[,1]),sum(dfDog$Age=="40-49")/length(dfDog[,1]),sum(dfDog$Age=="50-59")/length(dfDog[,1]),sum(dfDog$Age=="60-69")/length(dfDog[,1]),sum(dfDog$Age=="70-79")/length(dfDog[,1]))
Engine<-c(sum(dfEng$Age=="18-29")/length(dfEng[,1]),sum(dfEng$Age=="30-39")/length(dfEng[,1]),sum(dfEng$Age=="40-49")/length(dfEng[,1]),sum(dfEng$Age=="50-59")/length(dfEng[,1]),sum(dfEng$Age=="60-69")/length(dfEng[,1]),sum(dfEng$Age=="70-79")/length(dfEng[,1]))

Age<-c("18-29", "30-39", "40-49","50-59", "60-69", "70-79")
Top<-Top*100
Nature<-Nature*100
Manmade<-Manmade*100
Dog<-Dog*100
Engine<-Engine*100

df=data.frame(Age, Top, Nature, Manmade, Dog, Engine)
datm <- melt(df)
datm$Age<-as.factor(datm$Age)
head(datm)

p1<-ggplot(datm,aes(x = variable, y = value,fill = Age)) + 
	geom_bar(position = "fill",stat = "identity") +
	scale_y_continuous(labels=percent_format())+
	theme_bw()+
	labs(x="Study", y="Percentage")+
	scale_fill_manual(values = c("18-29"="deepskyblue","30-39"="chartreuse4","40-49"= "firebrick","50-59"="grey39","60-69"="violetred2","70-79"= "yellow2"))+
	theme(
	axis.title=title.text,
	axis.text=tick.text,
	legend.text=title.text,
	panel.grid	= element_blank(),
#	legend.title=element_blank(),
	legend.background = element_rect(fill = "white")
)

#--- Sex
Top<-c(sum(dfTop$Sex=="Male")/length(dfTop[,1]),sum(dfTop$Sex=="Female")/length(dfTop[,1]),sum(dfTop$Sex=="Rather not say")/length(dfTop[,1]))
Nature<-c(sum(dfNat$Sex=="Male")/length(dfNat[,1]),sum(dfNat$Sex=="Female")/length(dfNat[,1]),sum(dfNat$Sex=="Rather not say")/length(dfNat[,1]))
Manmade<-c(sum(dfMan$Sex=="Male")/length(dfMan[,1]),sum(dfMan$Sex=="Female")/length(dfMan[,1]),sum(dfMan$Sex=="Rather not say")/length(dfMan[,1]))
Dog<-c(sum(dfDog$Sex=="Male")/length(dfDog[,1]),sum(dfDog$Sex=="Female")/length(dfDog[,1]),sum(dfDog$Sex=="Rather not say")/length(dfDog[,1]))
Engine<-c(sum(dfEng$Sex=="Male")/length(dfEng[,1]),sum(dfEng$Sex=="Female")/length(dfEng[,1]),sum(dfEng$Sex=="Rather not say")/length(dfEng[,1]))

Sex<-c("Male", "Female", "Rather not say")
Top<-Top*100
Nature<-Nature*100
Manmade<-Manmade*100
Dog<-Dog*100
Engine<-Engine*100

df=data.frame(Sex, Top, Nature, Manmade, Dog, Engine)
datm <- melt(df)
datm$Sex<-as.factor(datm$Sex)
head(datm)
p2<-ggplot(datm,aes(x = variable, y = value,fill = Sex)) + 
	geom_bar(position = "fill",stat = "identity") +
	scale_y_continuous(labels=percent_format())+
	theme_bw()+
	labs(x="Study", y="Percentage")+
	scale_fill_manual(values = c("Male"="deepskyblue","Female"="chartreuse4","Rather not say"= "firebrick"))+
	theme(
	axis.title=title.text,
	axis.text=tick.text,
	legend.text=title.text,
	panel.grid	= element_blank(),
#	legend.title=element_blank(),
	legend.background = element_rect(fill = "white")
)

#--- Audio
Top<-c(sum(dfTop$Audio=="Yes")/length(dfTop[,1]),sum(dfTop$Audio=="No")/length(dfTop[,1]))
Nature<-c(sum(dfNat$Audio=="Yes")/length(dfNat[,1]),sum(dfNat$Audio=="No")/length(dfNat[,1]))
Manmade<-c(sum(dfMan$Audio=="Yes")/length(dfMan[,1]),sum(dfMan$Audio=="No")/length(dfMan[,1]))
Dog<-c(sum(dfDog$Audio=="Yes")/length(dfDog[,1]),sum(dfDog$Audio=="No")/length(dfDog[,1]))
Engine<-c(sum(dfEng$Audio=="Yes")/length(dfEng[,1]),sum(dfEng$Audio=="No")/length(dfEng[,1]))



Audio<-c("Yes", "No")
Top<-Top*100
Nature<-Nature*100
Manmade<-Manmade*100
Dog<-Dog*100
Engine<-Engine*100

df=data.frame(Audio, Top, Nature, Manmade, Dog, Engine)
datm <- melt(df)
datm$Audio<-as.factor(datm$Audio)
head(datm)
p3<-ggplot(datm,aes(x = variable, y = value,fill = Audio)) + 
	geom_bar(position = "fill",stat = "identity") +
	scale_y_continuous(labels=percent_format())+
	theme_bw()+
	labs(x="Study", y="Percentage")+
	scale_fill_manual(values = c("Yes"="deepskyblue","No"="chartreuse4"))+
	theme(
	axis.title=title.text,
	axis.text=tick.text,
	legend.text=title.text,
	panel.grid	= element_blank(),
#	legend.title=element_blank(),
	legend.background = element_rect(fill = "white")
)
#----



setEPS()
postscript("demo.eps", width=8, height=21)

grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=3, ncol=1)))

print(p1, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
grid.text("A", vp = viewport(layout.pos.row = 1, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p2, vp = viewport(layout.pos.row = 2, layout.pos.col = 1))
grid.text("B", vp = viewport(layout.pos.row = 2, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p3, vp = viewport(layout.pos.row = 3, layout.pos.col = 1))
grid.text("C", vp = viewport(layout.pos.row = 3, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))


dev.off()